Index: src/crankshaft/x87/lithium-codegen-x87.cc |
diff --git a/src/crankshaft/x87/lithium-codegen-x87.cc b/src/crankshaft/x87/lithium-codegen-x87.cc |
index c72483ede33321ef757b194ac1ed48e5d68872d0..4bc3183f01117fdece1b53fd90342bf429ce5c2e 100644 |
--- a/src/crankshaft/x87/lithium-codegen-x87.cc |
+++ b/src/crankshaft/x87/lithium-codegen-x87.cc |
@@ -3317,11 +3317,12 @@ void LCodeGen::DoLoadKeyedFixedArray(LLoadKeyed* instr) { |
__ j(not_equal, &done); |
if (info()->IsStub()) { |
// A stub can safely convert the hole to undefined only if the array |
// protector cell contains (Smi) Isolate::kArrayProtectorValid. Otherwise |
// it needs to bail out. |
- __ mov(result, isolate()->factory()->array_protector()); |
+ __ LoadRoot(result, Heap::kArrayElementsProtectorRootIndex); |
__ cmp(FieldOperand(result, PropertyCell::kValueOffset), |
- Immediate(Smi::FromInt(Isolate::kArrayProtectorValid))); |
+ Immediate(Smi::FromInt(Isolate::kArrayElementsProtectorValid))); |
DeoptimizeIf(not_equal, instr, Deoptimizer::kHole); |
} |
__ mov(result, isolate()->factory()->undefined_value()); |
@@ -3317,11 +3317,12 @@ void LCodeGen::DoLoadKeyedFixedArray(LLoadKeyed* instr) { |
if (info()->IsStub()) { |
// A stub can safely convert the hole to undefined only if the array |
- // protector cell contains (Smi) Isolate::kArrayProtectorValid. Otherwise |
+ // protector cell contains (Smi) Isolate::kArrayElementsProtectorValid. |
+ // Otherwise |
// it needs to bail out. |